package com.landray.kmss.sys.attachment.jg;

import java.util.Date;
import com.landray.kmss.util.StringUtil;
import java.util.Calendar;
import com.landray.kmss.util.IDGenerator;
import java.io.File;
import com.landray.kmss.util.FileUtil;
import com.landray.kmss.util.ResourceUtil;
import java.util.Collection;
import com.landray.kmss.util.ArrayUtil;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.attachment.util.ConsistentHash;
import org.slf4j.Logger;

public class JGFilePathUtil
{
    private static final Logger logger;
    public static final String SEPARATOR = "/";
    private static final String[] jg_extendPath;
    private static final ConsistentHash<String> filePathHash;
    
    static {
        logger = LoggerFactory.getLogger(JGFilePathUtil.class);
        jg_extendPath = new String[] { "extends1", "extends2", "extends3", "extends4", "extends5", "extends6" };
        filePathHash = new ConsistentHash((Collection)ArrayUtil.convertArrayToList((Object[])JGFilePathUtil.jg_extendPath));
    }
    
    public static String getHomeFilesPath() {
        final String dir = String.valueOf(ResourceUtil.KMSS_RESOURCE_PATH) + "/" + "JG_HTML";
        try {
            FileUtil.createDir(dir, true);
        }
        catch (final Exception ex) {}
        return dir;
    }
    
    public static File getFile(final String id, final String pathFix, final String fileName) {
        String root = getHomeFilesPath();
        final Date cteated = IDGenerator.getIDCreateTime(id);
        final Calendar cal = Calendar.getInstance();
        cal.setTime(cteated);
        File file = new File(String.valueOf(root) + "/" + cal.get(1) + "/" + (cal.get(2) + 1) + "/" + cal.get(5) + "/" + fileName);
        if (!file.exists()) {
            try {
                if (StringUtil.isNotNull(pathFix)) {
                    root = String.valueOf(root) + "/" + pathFix;
                }
                file = new File(String.valueOf(root) + "/" + fileName);
            }
            catch (final Exception e) {
                if (JGFilePathUtil.logger.isDebugEnabled()) {
                    JGFilePathUtil.logger.debug("解析文档ID出错，将采用散列式存储，解析出错id为：" + id + ",错误信息：" + e);
                }
                file = new File(String.valueOf(root) + "/" + (String)JGFilePathUtil.filePathHash.get((Object)id) + fileName);
                return file;
            }
        }
        return file;
    }
    
    public static String genFilePath(final String id, final String pathFix) {
        String root = String.valueOf(getHomeFilesPath()) + "/";
        if (StringUtil.isNotNull(pathFix)) {
            root = String.valueOf(root) + pathFix + "/";
        }
        try {
            final Date cteated = IDGenerator.getIDCreateTime(id);
            final Calendar cal = Calendar.getInstance();
            cal.setTime(cteated);
            return String.valueOf(root) + cal.get(1) + "/" + (cal.get(2) + 1) + "/" + cal.get(5) + "/";
        }
        catch (final Exception e) {
            if (JGFilePathUtil.logger.isDebugEnabled()) {
                JGFilePathUtil.logger.debug("解析文档ID出错，将采用散列式存储路径，解析出错id为：" + id + ",错误信息：" + e);
            }
            return String.valueOf(root) + (String)JGFilePathUtil.filePathHash.get((Object)id) + "/";
        }
    }
}
